#!/usr/bin/python
# Copyright 2007 by Bdale Garbee <bdale@gag.com>.  GPLv2
#
# Program to emit PCB footprint for Taoglas AP.10[CD] GPS antenna
#

# dimensions in mm from Taoglas datasheets
PinWidth = 1.25
PinHeight = 2.10
Edge2Side = 3.45
Edge2Back = 5.85
BackSpacking = 1.40
Offset = 1.05
HoleDiam = 1.50
Edge2Hole = 1.90
HoleSpacing = 9.70

import sys

# we're going to use the 1/100 of a mil fundamental unit form
def mm2mils100( mm ):
	return int( mm / 25.4 * 1000.0 * 100.0 + 0.5 )

print '# author: Bdale Garbee'
print '# email: bdale@gag.com'
print '# dist-license: GPL 2'
print '# use-license: unlimited'

print 'Element[0x0 "AP.10" "" "" 0 0 0 0 0 100 0x0]'
print "("
print '   Pad[',\
 	mm2mils100(-PinHeight/2 + PinWidth/2), \
	mm2mils100(Edge2Back + PinWidth/2), \
 	mm2mils100(PinHeight/2 - PinWidth/2), \
	mm2mils100(Edge2Back + PinWidth/2), \
	mm2mils100(PinWidth), \
	600, \
  	mm2mils100(PinWidth + 0.1), \
	'"pin1" "1" 0x0100]'

print '   Pad[',\
 	mm2mils100(-(PinHeight + BackSpacking + PinHeight/2 - PinWidth/2)), \
	mm2mils100(Edge2Back + PinWidth/2), \
 	mm2mils100(-(BackSpacking + PinHeight/2 + PinWidth/2)), \
	mm2mils100(Edge2Back + PinWidth/2), \
	mm2mils100(PinWidth), \
	600, \
  	mm2mils100(PinWidth + 0.1), \
	'"G" "2" 0x0100]'

print '   Pad[',\
 	mm2mils100((PinHeight + BackSpacking + PinHeight/2) - PinWidth/2), \
	mm2mils100(Edge2Back + PinWidth/2), \
 	mm2mils100((BackSpacking + PinHeight/2) + PinWidth/2), \
	mm2mils100(Edge2Back + PinWidth/2), \
	mm2mils100(PinWidth), \
	600, \
  	mm2mils100(PinWidth + 0.1), \
	'"G" "2" 0x0100]'

print '   Pad[',\
 	mm2mils100(-(Offset + PinHeight + BackSpacking + PinHeight/2 - PinWidth/2)), \
	mm2mils100(Edge2Side + PinWidth/2), \
 	mm2mils100(-(Offset + PinHeight + BackSpacking + PinHeight/2 - PinWidth/2)), \
	mm2mils100(Edge2Side +PinHeight - PinWidth/2), \
	mm2mils100(PinWidth), \
	600, \
  	mm2mils100(PinWidth + 0.1), \
	'"G" "2" 0x0100]'

print '   Pad[',\
 	mm2mils100((Offset + PinHeight + BackSpacking + PinHeight/2 - PinWidth/2)), \
	mm2mils100(Edge2Side + PinWidth/2), \
 	mm2mils100((Offset + PinHeight + BackSpacking + PinHeight/2 - PinWidth/2)), \
	mm2mils100(Edge2Side +PinHeight - PinWidth/2), \
	mm2mils100(PinWidth), \
	600, \
  	mm2mils100(PinWidth + 0.1), \
	'"G" "2" 0x0100]'

print '   Pin[',\
        mm2mils100(-HoleSpacing/2), \
        mm2mils100(Edge2Hole), \
        mm2mils100(HoleDiam) + 1200, \
        600, \
        mm2mils100(HoleDiam) + 1800, \
        mm2mils100(HoleDiam), \
        '"G" "2" 0x0000]'


print '   Pin[',\
        mm2mils100(HoleSpacing/2), \
        mm2mils100(Edge2Hole), \
        mm2mils100(HoleDiam) + 1200, \
        600, \
        mm2mils100(HoleDiam) + 1800, \
        mm2mils100(HoleDiam), \
        '"G" "2" 0x0000]'


print ")"
