#!/usr/bin/python
# Copyright 2008 by Bdale Garbee <bdale@gag.com>.  GPLv2
#
# Program to emit PCB footprint for DFN10 package used by Microchip MCP73837
#

# dimensions in mm from the Microchip en012702.pdf datasheet
PinWidth = 0.30		
PinResist = 0.402		# width of gap in solder resist over pad
PinHeight = 0.65
PinSpacing = 0.50
RowSpacing = 3.10
PaddleLength = 2.48
PaddleWidth = 1.55
Length = 3.00
Width = 3.00

import sys

# we're going to use the 1/100 of a mil fundamental unit form
def mm2mils100( mm ):
	return int( mm / 25.4 * 1000.0 * 100.0 + 0.5 )

print '# author: Bdale Garbee'
print '# email: bdale@gag.com'
print '# dist-license: GPL 2'
print '# use-license: unlimited'

print 'Element[0x0 "DFN10" "" "" 0 0 0 0 0 100 0x0]'
print "("

# pad under the chip, must be grounded
print '   Pad[',\
 	mm2mils100(-PaddleLength/2 + PaddleWidth/2), \
	mm2mils100(0), \
	mm2mils100(PaddleLength/2 - PaddleWidth/2), \
	mm2mils100(0), \
	mm2mils100(PaddleWidth), \
	0, \
	mm2mils100(PaddleWidth)+600, \
	'"pin11" "11" "square"]'

## vias in the ground pad under the chip
for viarow in range (-1,2,2):
  for viacol in range (-1,2):
    print '   Pin[',\
	mm2mils100(viacol * PaddleLength / 3), \
 	mm2mils100(viarow * PaddleWidth / 4), \
	2900, \
	2500, \
 	0, \
  	1500, \
	'"pin11" "11" 0x0002]'

# pins
for pin in range (1,6):
    print '   Pad[',\
 	mm2mils100((pin - 3) * PinSpacing), \
	mm2mils100(-RowSpacing/2 + PinHeight/2 - PinWidth/2), \
 	mm2mils100((pin - 3) * PinSpacing), \
	mm2mils100(-RowSpacing/2 - PinHeight/2 + PinWidth/2), \
	mm2mils100(PinWidth), \
	mm2mils100(PinSpacing - PinWidth), \
	mm2mils100(PinResist), \
	'"pin%i"' % (11-pin), '"%i"' % (11-pin), '"square"]'

    print '   Pad[',\
 	mm2mils100((pin - 3) * PinSpacing), \
	mm2mils100(+RowSpacing/2 - PinHeight/2 + PinWidth/2), \
 	mm2mils100((pin - 3) * PinSpacing), \
	mm2mils100(+RowSpacing/2 + PinHeight/2 - PinWidth/2), \
	mm2mils100(PinWidth), \
	mm2mils100(PinSpacing - PinWidth), \
	mm2mils100(PinResist), \
	'"pin%i"' % pin, '"%i"' % pin, '"square"]'

#    print '   Pad[',\
# 	mm2mils100(-2.5 + pin * PinSpacing), \
#	mm2mils100(+PinSpacing/2 - PinHeight + PinWidth/2), \
# 	mm2mils100(-2.5 + pin * PinSpacing), \
#	mm2mils100(+PinSpacing/2 - PinWidth/2), \
#	mm2mils100(PinWidth), \
#	mm2mils100(PinSpacing - PinWidth), \
#	mm2mils100(PinResist), \
#	'"pin%i"' % pin, '"%i"' % pin, '0x0000]'

print '   ElementLine[',\
 	-mm2mils100(Length/2), \
 	-mm2mils100(Width/2), \
 	mm2mils100(Length/2), \
 	-mm2mils100(Width/2), \
	500, \
	']'
print '   ElementLine[',\
 	-mm2mils100(Length/2), \
	-mm2mils100(Width/2), \
 	-mm2mils100(Length/2), \
	mm2mils100(Width/2), \
	500, \
	']'
print '   ElementLine[',\
 	-mm2mils100(Length/2), \
	mm2mils100(Width/2), \
 	mm2mils100(Length/2), \
	mm2mils100(Width/2), \
	500, \
	']'
print '   ElementLine[',\
 	mm2mils100(Length/2), \
	mm2mils100(Width/2), \
 	mm2mils100(Length/2), \
	-mm2mils100(Width/2), \
	500, \
	']'

print '   ElementArc[',\
	mm2mils100(-Length/2), \
	mm2mils100(Width/2), \
	'500 500 0 360 1000 ]'
print ")"
